@@ -7,14 +7,12 @@ from hellodeploy.settings import CRED_PATH, OPT_PATH
 
 def main():
     credentials = os.path.exists(CRED_PATH)
-    options = os.path.exists(OPT_PATH)
 
     if 'init' in sys.argv:
         f = open(OPT_PATH, 'w+')
         f.close()
 
-    if options:
-        data, options = extract_options()
+    data, options = extract_options()
     if credentials:
         f = open(CRED_PATH, 'r')
         token = f.read()
