@@ -10,11 +10,30 @@ from hellodeploy.settings import ACCEPTED_DBS, ACCEPTED_LANGS, BASE_URL, CRED_PA
 if '--local' in sys.argv:
     BASE_URL = 'http://localhost:8000'
 
+def get_ignored(gitignore):
+    ignore = []
+    for line in gitignore:
+        line = line.strip()
+        if line and line[0] != '#':
+            if line[0] == '/':
+                line = line[1:]
+            ignore.append(line)
+    return ignore
+
 def zipdir(path, ziph):
     # ziph is zipfile handle
+    gitignore = os.path.exists('.gitignore')
+    gitignore = open('.gitignore', 'r')
+    files_to_ignore = get_ignored(gitignore)
     for root, dirs, files in os.walk(path):
+        files = [f for f in files if not f[0] == '.']
+        dirs[:] = [d for d in dirs if not d[0] == '.']
+        ignore = list(set(dirs).intersection(files_to_ignore))
+        for i in ignore:
+            dirs.remove(i)
         for file in files:
-            ziph.write(os.path.join(root, file))
+            if file not in files_to_ignore:
+                ziph.write(os.path.join(root, file))
 
 def extract_options():
     options = os.path.exists(OPT_PATH)
@@ -76,10 +95,10 @@ def upload(token, data, options):
         sys.stdout.write('Do you want to zip current contents(z) of dir or upload your own zip file(u): ')
         options['zip_option'] = input()
     if options['zip_option'] == 'z':
-        zipf = zipfile.ZipFile('.Archive.zip', 'w', zipfile.ZIP_DEFLATED)
+        zipf = zipfile.ZipFile('.zipignore', 'w', zipfile.ZIP_DEFLATED)
         zipdir('.', zipf)
         zipf.close()
-        files = {'files': open('.Archive.zip', 'rb')}
+        files = {'files': open('.zipignore', 'rb')}
     elif options['zip_option'] == 'u':
         sys.stdout.write('Please input the path of the project zip file: ')
         options['zip_file'] = input()
@@ -131,7 +150,7 @@ def upload(token, data, options):
                 data['db_env'] = input()
     headers = {'Authorization': 'Token ' + token}
     r = requests.post(BASE_URL + '/api/upload/', data=data, headers=headers, files=files)
-    os.remove('.Archive.zip')
+    os.remove('.zipignore')
     f = open(OPT_PATH, 'w+')
     f.write(json.dumps(data) + '\n')
     f.write(json.dumps(options))
